import { act, render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import ReportOptions from 'components/Options/ReportOptions/ReportOptions'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.slice'
import { fluidStatusConnectedData } from 'tests/__mocks__/fluidStatusData.mock'
import {
  createMockEcolyoStore,
  mockGlobalState,
  mockProfileState,
} from 'tests/__mocks__/store'

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    updateProfile: mockUpdateProfile,
  }))
})

const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

describe('ReportOptions component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered with sendAnalysisNotification to true', () => {
    render(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    expect(screen.getAllByRole('checkbox')[0]).toBeChecked()
  })

  it('should update the profile with sendAnalysisNotification to false', async () => {
    render(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getAllByRole('checkbox')[0])
    })
    expect(updateProfileSpy).toHaveBeenCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: false,
    })
  })
  it('should be rendered with sendAnalysisNotification false and toggle it to true', async () => {
    const store = createMockEcolyoStore({
      global: mockGlobalState,
      profile: { ...mockProfileState, sendAnalysisNotification: false },
    })
    render(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getAllByRole('checkbox')[0])
    })
    expect(updateProfileSpy).toHaveBeenCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: true,
    })
  })

  describe('should test water alert', () => {
    const storeWaterDone = createMockEcolyoStore({
      global: { ...mockGlobalState, fluidStatus: fluidStatusConnectedData },
      profile: { ...mockProfileState, sendAnalysisNotification: false },
    })
    it('should be rendered with sendConsumptionAlert to false and enable it', async () => {
      render(
        <Provider store={storeWaterDone}>
          <ReportOptions />
        </Provider>
      )
      expect(screen.getAllByRole('checkbox')[1]).not.toBeChecked()
      await act(async () => {
        await userEvent.click(screen.getAllByRole('checkbox')[1])
      })
      expect(updateProfileSpy).toHaveBeenCalledTimes(1)
      expect(updateProfileSpy).toHaveBeenCalledWith({
        sendConsumptionAlert: true,
      })
    })

    it('should render waterLimit to 100', () => {
      const storeWaterAlert = createMockEcolyoStore({
        global: { ...mockGlobalState, fluidStatus: fluidStatusConnectedData },
        profile: {
          ...mockProfileState,
          sendConsumptionAlert: true,
          waterDailyConsumptionLimit: 100,
        },
      })
      render(
        <Provider store={storeWaterAlert}>
          <ReportOptions />
        </Provider>
      )
      expect(screen.getByRole('spinbutton')).toHaveValue(100)
    })
  })
})
