import { TimeStep } from 'enums'
import { DateTime } from 'luxon'
import { graphData } from 'tests/__mocks__/chartData.mock'
import { mockChartState } from 'tests/__mocks__/store'
import {
  chartSlice,
  setCurrentDataChart,
  setCurrentDataChartIndex,
  setCurrentIndex,
  setCurrentTimeStep,
  setSelectedDate,
  setShowCompare,
  setShowConnectionDetails,
} from './chart.slice'

describe('chart reducer', () => {
  it('should return the initial state', () => {
    const initialState = chartSlice.getInitialState()
    expect(initialState).toEqual(mockChartState)
  })

  it('should return same state if no action', () => {
    const state = chartSlice.getInitialState()
    expect(state).toEqual(mockChartState)
  })

  describe('setSelectedDate', () => {
    it('should handle setSelectedDate with payload', () => {
      const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const state = chartSlice.reducer(
        mockChartState,
        setSelectedDate(mockDate)
      )
      expect(state).toEqual({
        ...mockChartState,
        selectedDate: mockDate,
      })
    })
  })

  describe('setCurrentTimeStep', () => {
    it('should handle setCurrentTimeStep with payload', () => {
      const state = chartSlice.reducer(
        mockChartState,
        setCurrentTimeStep(TimeStep.MONTH)
      )
      expect(state).toEqual({
        ...mockChartState,
        currentTimeStep: TimeStep.MONTH,
      })
    })
    it('should disable showCompare if timestep is year', () => {
      const state = chartSlice.reducer(
        { ...mockChartState, showCompare: true },
        setCurrentTimeStep(TimeStep.YEAR)
      )
      expect(state).toEqual({
        ...mockChartState,
        showCompare: false,
        currentTimeStep: TimeStep.YEAR,
      })
    })
  })

  describe('setCurrentIndex', () => {
    it('should handle setCurrentIndex with payload', () => {
      const state = chartSlice.reducer(mockChartState, setCurrentIndex(1))
      expect(state).toEqual({
        ...mockChartState,
        currentIndex: 1,
      })
    })
  })

  describe('setCurrentDataChart', () => {
    it('should handle setCurrentDataChart with payload', () => {
      const state = chartSlice.reducer(
        mockChartState,
        setCurrentDataChart(graphData)
      )
      expect(state).toEqual({
        ...mockChartState,
        currentDatachart: graphData,
      })
    })
  })

  describe('setCurrentDataChartIndex', () => {
    it('should handle setCurrentDataChartIndex with payload', () => {
      const state = chartSlice.reducer(
        mockChartState,
        setCurrentDataChartIndex(1)
      )
      expect(state).toEqual({
        ...mockChartState,
        currentDatachartIndex: 1,
      })
    })
  })

  describe('setShowCompare', () => {
    it('should handle setShowCompare', () => {
      const state = chartSlice.reducer(mockChartState, setShowCompare(true))
      expect(state).toEqual({
        ...mockChartState,
        showCompare: true,
      })
    })
  })

  describe('setShowConnectionDetails', () => {
    it('should handle setShowConnectionDetails', () => {
      const state = chartSlice.reducer(
        mockChartState,
        setShowConnectionDetails(true)
      )
      expect(state).toEqual({
        ...mockChartState,
        showConnectionDetails: true,
      })
    })
  })
})
